@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12526 2020-09-24 10:42:30Z Casey $
+# $Id: cms_dumpdata.py 12545 2020-10-08 07:18:50Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2020-09-24 18:42:30 +0800 (Thu, 24 Sep 2020) $
-# $Revision: 12526 $
+# $Date: 2020-10-08 15:18:50 +0800 (Thu, 08 Oct 2020) $
+# $Revision: 12545 $
 
 import os
 import sys
@@ -74,6 +74,9 @@ class Command(BaseCommand):
                 use_natural_foreign_keys=True, use_natural_primary_keys=True,
                 stream=dataStream)
         else:
+        	if options['permissionAndContenttypes']:
+                raise RuntimeError('Your django version does not provide this usage(-pc).')
+                
             serializers.serialize(
                 'json', getObjects(), indent=2,
                     use_natural_keys=True, stream=dataStream)
