@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_loaddata.py 12280 2020-05-28 08:02:42Z Lavender $
+# $Id: cms_loaddata.py 12526 2020-09-24 10:42:30Z Casey $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,27 +11,36 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-05-28 16:02:42 +0800 (Thu, 28 May 2020) $
-# $Revision: 12280 $
+# $Author: Casey $
+# $Date: 2020-09-24 18:42:30 +0800 (Thu, 24 Sep 2020) $
+# $Revision: 12526 $
 
 import json
 
 from django.core.management.base import BaseCommand
 from django.core.management import call_command
-
+from django.contrib.auth.models import Permission
+from django.contrib.contenttypes.models import ContentType
 from filer.models.imagemodels import Image
 
 class Command(BaseCommand):
-    
+
     help = 'Fixed filer image from dumpdata'
 
     def add_arguments(self, parser):
         parser.add_argument('data', type=str, help="data json")
-    
+        parser.add_argument(
+            '-pc', '--permissionAndContenttypes',
+            action='store_true',
+            help="Load auth(permission) and contenttypes data.")
+
     def handle(self, *args, **options):
+        if options['permissionAndContenttypes']:
+            Permission.objects.all().delete()
+            ContentType.objects.all().delete()
+
         dataJson = options['data']
-        call_command('loaddata', dataJson)  
+        call_command('loaddata', dataJson)
 
         with open(dataJson, encoding="utf-8") as data:
             allData = json.loads(data.read())
@@ -43,7 +52,7 @@ class Command(BaseCommand):
         for imgData in imageData:
             image = Image.objects.get(id=imgData['pk'])
             image.file_data_changed()
-            
 
 
-        
+
+
